@@ -2,36 +2,22 @@ package optimizer;
 use Carp;
 use B;
 { no warnings 'redefine';
-  use B::Generate;
+use B::Generate;
 }
-use 5.007002;
+use 5.7.2;
 use strict;
 use warnings;
 
-BEGIN {
-  # op_seq workaround for 5.10, store it as package global.
-  my $seq = 0;
-  if ($] > 5.009) {
-    eval q(
-      package B::OP;
-      sub seq {
-        shift;
-        @_ ? $optimizer::seq = shift : $optimizer::seq;
-      }
-    );
-  }
-}
-
 require DynaLoader;
-our $VERSION = '0.06_07';
+our $VERSION = '0.01';
 our @ISA=q(DynaLoader);
-our %callbacks;
+
 bootstrap optimizer $VERSION;
 
 my ($file, $line) = ("unknown", "unknown");
 
 {
-sub preparewarn {
+sub preparewarn { 
     my $args = join '', @_;
     $args = "Something's wrong " unless $args;
     $args .= " at $file line $line.\n" unless substr($args, length($args) -1) eq "\n";
@@ -61,12 +47,7 @@ sub import {
         optimizer::install( sub { callbackoptimizer($_[0],$subref) }) if $type eq "callback";
         optimizer::install( sub { optimizer::peepextend($_[0], $subref) }) if $type eq "extend";
         optimizer::install( $subref ) if $type eq "mine";
-    } elsif ($type eq 'extend-c') {
-      optimizer::c_extend_install(shift);
-    } elsif ($type eq 'sub-detect') {
-      my ($package, $filename, $line) = caller;
-      $callbacks{$package} = shift;
-      optimizer::c_sub_detect_install();
+
     } else { croak "Unknown optimizer option '$type'"; }
 }
 
@@ -77,9 +58,9 @@ sub unimport {
 sub callbackoptimizer {
     my ($op, $callback) = @_;
     while ($$op) {
-	$op->seq(optimizer::op_seqmax_inc());
+        $op->seq(optimizer::op_seqmax_inc());
         update($op) if $op->isa("B::COP");
-        relocatetopad($op, $op->find_cv()) if $op->name eq "const"; # For thread safety
+        relocatetopad($op) if $op->name eq "const"; # For thread safety
 
         $callback->($op);
         $op = $op->next;
@@ -106,7 +87,7 @@ sub peepextend {
             optimizer::die("Bareword ",$o->sv->sv, " not allowed while \"strict subs\" in use")
                 if ($o->private & 8);
 
-            relocatetopad($o,$o->find_cv());
+            relocatetopad($o);
             $o->seq(optimizer::op_seqmax_inc());
         } elsif ($o->name eq "concat") {
             if ($o->next && $o->next->name eq "stringify" and !($o->flags &64)) {
@@ -114,7 +95,7 @@ sub peepextend {
                     $o->targ($o->next->targ);
                     $o->next->targ(0);
                 }
-                #$o->null;
+                $o->null;
             }
             $o->seq(optimizer::op_seqmax_inc());
         #} elsif ($o->name eq "stub") {
@@ -128,7 +109,7 @@ sub peepextend {
                 next;
             }
             $o->seq(optimizer::op_seqmax_inc());
-        #} elsif ($o->name eq "gv") {
+        #} elsif ($o->name eq "gv") { 
         #    CORE::die "Eep.";
         } elsif ($o->name =~ /^((map|grep)while|(and|or)(assign)?|cond_expr|range)$/) {
             $o->seq(optimizer::op_seqmax_inc());
@@ -136,16 +117,12 @@ sub peepextend {
             peepextend($o->other, $callback); # Weee.
         } elsif ($o->name =~ /^enter(loop|iter)/) {
             $o->seq(optimizer::op_seqmax_inc());
-            $o->redoop($o->redoop->next) while $o->redoop->name eq "null";
-	    peepextend($o->redoop, $callback);
-            $o->nextop($o->nextop->next) while $o->nextop->name eq "null";
-	    peepextend($o->nextop, $callback);
-            $o->lastop($o->lastop->next) while $o->lastop->name eq "null";
-	    peepextend($o->lastop, $callback);
+            $o->redoop($o->redoop->next) while $o->redoop->name eq "null"; peepextend($o->redoop, $callback);
+            $o->nextop($o->nextop->next) while $o->nextop->name eq "null"; peepextend($o->nextop, $callback);
+            $o->lastop($o->lastop->next) while $o->lastop->name eq "null"; peepextend($o->lastop, $callback);
         } elsif ($o->name eq "qr" or $o->name eq "match" or $o->name eq "subst") {
             $o->seq(optimizer::op_seqmax_inc());
-            $o->pmreplstart($o->pmreplstart->next)
-	      while ${$o->pmreplstart} and $o->pmreplstart->name eq "null";
+            $o->pmreplstart($o->pmreplstart->next) while ${$o->pmreplstart} and $o->pmreplstart->name eq "null"; 
             peepextend($o->pmreplstart, $callback);
         } elsif ($o->name eq "exec") {
             $o->seq(optimizer::op_seqmax_inc());
@@ -165,10 +142,11 @@ sub peepextend {
         $o = $o->next;
         last unless $o->can("next"); # Shouldn't get here
     }
-}
+}    
 
 1;
 __END__
+# Below is stub documentation for your module. You better edit it!
 
 =head1 NAME
 
@@ -177,10 +155,10 @@ optimizer - Write your own Perl optimizer, in Perl
 =head1 SYNOPSIS
 
   # Use Perl's default optimizer
-  use optimizer 'C';
+  use optimizer 'C'; 
 
   # Use a Perl implementation of the default optimizer
-  use optimizer 'perl';
+  use optimizer 'perl'; 
 
   # Use an extension of the default optimizer
   use optimizer extend => sub {
@@ -190,17 +168,9 @@ optimizer - Write your own Perl optimizer, in Perl
   # Use a simple optimizer with callbacks for each op
   use optimizer callback => sub { .. }
 
-  # Completely implement your own optimizer
+  # Completely implement your own optimizre
   use optimizer mine => sub { ... }
 
-  # use the standard optimizer with an extra callback
-  # this is the most compatible optimizer version
-  use optimizer 'extend-c' => sub { print $_[0]->name() };
-
-  # don't provide a peep optimizer, rather get a callback
-  # after we are finished with every code block
-  use optimizer 'sub-detect' => sub { print $_[0]->name() };
-
   no optimizer; # Use the simplest working optimizer
 
 =head1 DESCRIPTION
@@ -208,17 +178,18 @@ optimizer - Write your own Perl optimizer, in Perl
 This module allows you to replace the default Perl optree
 optimizer, C<peep>, with a Perl function of your own devising.
 
-It requires a Perl > 5.8 or patched with the plugpeep patch supplied
-with the module distribution; this patch allows the optimizer to be
+It requires a Perl patched with the patch supplied with the 
+module distribution; this patch allows the optimizer to be
 pluggable and replaceable with a C function pointer. This module
-provides the glue between the C function and a Perl subroutine.
-This patch was integrated as of perl 5.8.
+provides the glue between the C function and a Perl subroutine. It 
+is hoped that the patch will be integrated into the Perl core at 
+some point soon.
 
 Your optimizer subroutine will be handed a C<B::OP>-derived object
 representing the first (NOT the root) op in the program. You are
 expected to be fluent with the C<B> module to know what to do with this.
-You can use L<B::Generate> to fiddle around with the optree you are
-given, while traversing it in execution order.
+You can use C<B::Generate> to fiddle around with the optree you are
+given, while traversing it in execution order. 
 
 If you choose complete control over your optimizer, you B<must> assign
 sequence numbers to operations. This can be done via the
@@ -230,146 +201,19 @@ incremented sequence number. Do something like this:
 
         ... more optimizations ...
 
-        $op = $op->next;
+        $op = $op->next; 
         last unless $op->can("next"); # Shouldn't get here
     }
 
 The C<callback> option to this module will essentially do the above,
-calling your given subroutine with each op.
-
-If you just want to use this function to get a callback after every
-code block is compiled so you can do any arbitrary work on it use the
-C<sub-detect> option, you will be passed LEAVE* ops after the standard
-peep optimizer has been run, this minimises the risk for bugs as we
-use the standard one. The op tree you are handed is also stable so you
-are free to work on it. This is useful if you are limited by
-C<CHECK> and C<INIT> blocks as this works with string eval and
-C<require> aswell. Only one callback per package is allowed.
-
-PERL_DL_NONLAZY and B::Generate
-
-Note that optimizer do works fine on most platforms and perl versions,
-only on Windows some libperl functions are not exported anymore, which
-B::Generate needs.
-
-=head1 OPTIONS
-
-=over 4
-
-=item C
-
-Use Perl's default optimizer.
-
-  use optimizer 'C';
-
-=item perl
-
-Use a Perl implementation of Perl's default optimizer.
-
-  use optimizer 'perl';
-
-=item extend
-
-Use an extension of the default optimizer.
-The callback is called for every visited op.
-
-  use optimizer extend => sub {
-        warn "goto considered harmful" if $_[0]->name eq "goto"
-  }
-
-=item callback
-
-Use a simple optimizer with callbacks for each op.
-
-  use optimizer callback => sub { .. }
-
-=item mine
-
-Completely implement your own optimizer. You have to provide your own walker and peep.
-
-  use optimizer mine => sub { ... }
-
-=item extend-c
-
-Use the standard optimizer with an extra callback.
-This is the most compatible optimizer version.
-
-  use optimizer 'extend-c' => sub { print $_[0]->name() };
-
-=item sub-detect
-
-Don't provide a peep optimizer, rather get a callback
-after we are finished with every code block (I<sub>).
-You will be passed LEAVE* ops after the standard
-peep optimizer has been run, this minimises the risk
-for bugs as we use the standard one.
-
-  use optimizer 'sub-detect' => sub { print $_[0]->name() };
-
-=back
-
-=head1 HELPER FUNCTIONS
-
-=over 4
-
-=item callbackoptimizer (this, callback)
-
-The helper function for the option B<callback>.
-
-=item peepextend (this, callback)
-
-The helper function for the option B<extend>.
-
-->import('perl') uses B<peepextend> with an empty callback.
-
-=item c_extend_install
-
-The helper function for the option B<extend-c>.
-It uses the longish XS function C<c_extend_peep> as
-experimental peeper, and calls the user-side perl callback
-for each OP.
-
-=item c_sub_detect_install
-
-The XS helper function for the option B<sub-detect>.
-It installs C<c_sub_detect> as C<PL_peep>.
-B<c_sub_detect> calls all perl-side callbacks at any LEAVE op.
-
-=item relocatetopad
-
-For thread-safety we need to move a SV to a PAD.
-
-=item unimport
-
-Override with an empty B<callbackoptimizer>, effectively disabling any
-installed optimizer.
-
-=back
-
-=head1 STATUS
-
-relocatetopad fails with threaded perls.
-
-=head1 5.10 Changes
-
-Since Perl 5.10 there are no op_seqmax and op_seq numbers in CORE
-anymore, so we add a package global op_seqmax for the op-tree
-numbering, for $B::OP::seq also. This is not thread-safe.
+calling your given subroutine with each op. 
 
 =head1 AUTHOR
 
-  Simon Cozens, C<simon@cpan.org>
-
-Extended functionality:
-
-  Artur Bergman, C<abergman@cpan.org>
-
-5.10 support and current maintainer Reini Urban:
-
-  Reini Urban, C<rurban@cpan.org>
+Simon Cozens, C<simon@cpan.org>
 
 =head1 SEE ALSO
 
-L<B::Generate>, L<optimize>
+L<B::Generate>
 
 =cut
